import time

# Import the preset TestFixture.
from .Frames_capture_fixture import FixtureFramesCapture, ChannelFactory

from xtr import logging, Severity
logger = logging.getLogger(__name__)


# Create the test case class, that inherits from the preset TestFixture.
class TestCaptureLinFrames(FixtureFramesCapture):

    # This method will be executed just before
    # the test case method execution.
    def setUp(self):
        logger.info("Setup test case")

    # This method will be executed just after
    # the test case method execution.
    def tearDown(self):
        logger.info("Tear down test case")

    # Create the test case method that holds the main test steps.
    def test_capture_lin_frames(self):

        # Define frame properties.
        # The values provided below are arbitrary examples.
        # They do not belong to any actual in vehicle communication.
        channel_name = 'B1_LIN'
        frame_id = '0x30'
        payload = [0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF]

        lin_ch = ChannelFactory().get_lin_channel(channel_name)

        lin_fr = lin_ch.get_frame(frame_id)

        # Start listening on the lin channel.
        lin_ch.listener.start_listening()

        # Log any useful message
        logger.info("create and transmit a lin frame")

        lin_fr.transmitter.transmit_frame(payload)

        # Pause the program for 3 seconds.
        time.sleep(3)

        # Stop listening on the lin channel.
        lin_ch.listener.stop_listening()

        q = lin_ch.listener.get_queue()

        # Confirm that the queue is not Null object,
        # meaning there is no error in creating the queue.
        self.assertTrue(q is not None, Severity.BLOCKER,
                        "Error when listening to lin bus")

        # Confirm that queue is not empty meaning messages are received.
        self.assertTrue(not q.empty() >= 1, Severity.BLOCKER,
                        "Lin frame is not received")

        event = q.queue[0]
        logger.info(repr(event))

        logger.info(f"{event.channel_name}")
        logger.info(f"{event.frame_id}")
